#
# spec file for package xdemorse
#
# Copyright (c) 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with perseus-sdr
Name:           xdemorse
Version:        3.6.7
Release:        1.2
Summary:        Simple morse decoder for X11
License:        GPL-2.0-or-later
Group:          Productivity/Hamradio/Morse
URL:            https://www.qsl.net/5b4az/pages/morse.html
Source:         https://www.qsl.net/5b4az/pkg/morse/xdemorse/%{name}-%{version}.tar.bz2
Patch0:         xdemorse-3.6.7-xdemorserc-message.patch
BuildRequires:  c++_compiler
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
%if %{with perseus-sdr}
BuildRequires:  libperseus-sdr-devel
BuildRequires:  pkgconfig(libusb-1.0)
%endif

%description
Xdemorse is a simple morse decoder for X11.

%prep
%autosetup -p1

%build
%configure \
	--docdir=%{_docdir}/%{name} \
	%{nil}
%make_build

%install
%make_install
mv %{buildroot}%{_datadir}/examples/xdemorse/* %{buildroot}/%{_docdir}/%{name}

%check
%make_build check

%files
%license COPYING
%doc AUTHORS README
%{_bindir}/%{name}
%{_datadir}/pixmaps/%{name}.svg
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_docdir}/xdemorse/

%changelog
* Sat Feb 22 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 3.6.7, license is GPL-2.0-or-later
- replace xdemorse-fix-build.patch with spec construct
- Fix patch in message about xdemorserc during start-up
  xdemorse-3.6.7-xdemorserc-message.patch
* Wed Oct  2 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Fix build for Tumbleweed and Factory
* Wed Nov 10 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 3.6.5
  * see /usr/share/doc/packages/xdemorse/README for changelog
  * fixes build for latest relkeases (Leap 15.3 and Tumbleweed)
- Patch xdemorse-fix-build.patch rebased
* Thu Feb 21 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- add minimum version for gtk3
* Tue Jan  8 2019 mardnh@gmx.de
- Update to version 3.6.2
  * see /usr/share/doc/packages/xdemorse/README for changelog
- Specfile cleanup
- Add patch:
  - xdemorse-fix-build.patch
* Wed Mar 15 2017 dl8fcl@darc.de
- updated to version 3.0
* Wed Dec 31 2014 wk@ire.pw.edu.pl
- updated to version 2.9
* Mon Sep 15 2014 wk@ire.pw.edu.pl
- updated to version 2.8
* Fri Apr  4 2014 wk@ire.pw.edu.pl
- updated to version 2.7
* Wed Oct  9 2013 wk@ire.pw.edu.pl
- updated to version 2.5
* Fri Feb  3 2012 wk@ire.pw.edu.pl
- updated to version 2.3
- some cleanup to spec file
* Thu Aug  5 2010 dl8fcl@darc.de
- updated to version 2.1
- desktop file, icon and README_openSUSE added
* Fri Apr 17 2009 dl9pf@gmx.de
- updated to new version
* Sat Oct  4 2008 dl8fcl@darc.de
- updated for openSUSE_Factory
